@@ -1,5 +1,6 @@
-try:
-    import security
+from auth_token.utils import is_installed_security
+
+if is_installed_security:
     from .auth_security.resource import AuthResource
-except ImportError:
+else:
     from .default.resource import AuthResource
\ No newline at end of file
